@@ -44,11 +44,11 @@
 #include <limits.h>
 #include <ctype.h>
 
-#if defined(CPU_COUNT) && (CPU_COUNT + 0) < 2
-#undef CPU_COUNT
+#if defined(MHD_CPU_COUNT) && (MHD_CPU_COUNT + 0) < 2
+#undef MHD_CPU_COUNT
 #endif
-#if ! defined(CPU_COUNT)
-#define CPU_COUNT 2
+#if ! defined(MHD_CPU_COUNT)
+#define MHD_CPU_COUNT 2
 #endif
 
 #ifndef PATH_MAX
@@ -61,7 +61,7 @@
  * Number of threads to run in the thread pool.  Should (roughly) match
  * the number of cores on your system.
  */
-#define NUMBER_OF_THREADS CPU_COUNT
+#define NUMBER_OF_THREADS MHD_CPU_COUNT
 
 #ifdef MHD_HAVE_LIBMAGIC
 /**
@@ -286,11 +286,11 @@ list_directory (struct ResponseDataContext *rdc,
         snprintf (fullname, sizeof (fullname),
                   "%s/%s",
                   dirname, de->d_name))
-      continue; /* ugh, file too long? how can this be!? */
+      continue;  /* ugh, file too long? how can this be!? */
     if (0 != stat (fullname, &sbuf))
-      continue; /* ugh, failed to 'stat' */
+      continue;  /* ugh, failed to 'stat' */
     if (! S_ISREG (sbuf.st_mode))
-      continue; /* not a regular file, skip */
+      continue;  /* not a regular file, skip */
     if (rdc->off + 1024 > rdc->buf_len)
     {
       void *r;
