@@ -479,7 +479,7 @@ MHD_socket_set_nodelay_ (MHD_socket sock,
     return setsockopt (sock,
                        IPPROTO_TCP,
                        TCP_NODELAY,
-                       (const void *) (on) ? &on_val : &off_val,
+                       (const void *) ((on) ? &on_val : &off_val),
                        sizeof (on_val));
   }
 #else
@@ -516,10 +516,10 @@ MHD_socket_cork_ (MHD_socket sock,
                        (const void *) (on ? &on_val : &off_val),
                        sizeof (off_val)))
     return 0; /* failed */
-#if defined(__FreeBSD__) && __FreeBSD__ + 0 >= 9
-  /* FreeBSD do not need zero-send for flushing starting from version 9 */
+#if defined(_MHD_CORK_RESET_PUSH_DATA)
   return 1;
-#elif defined(TCP_NOPUSH) && ! defined(TCP_CORK)
+#else  /* ! _MHD_CORK_RESET_PUSH_DATA */
+  if (! on)
   {
     const int dummy = 0;
     /* Force flush data with zero send otherwise Darwin and some BSD systems
@@ -532,13 +532,13 @@ MHD_socket_cork_ (MHD_socket sock,
       return 0; /* even force flush failed!? */
     return 1; /* success */
   }
-#else
-  return 1; /* success */
-#endif
-#else
+  return 1;
+#endif /* ! _MHD_CORK_RESET_PUSH_DATA */
+#else  /* ! MHD_TCP_CORK_NOPUSH */
   /* do not have MHD_TCP_CORK_NOPUSH at all */
+  (void) sock; (void) on; /* Mute compiler warnings */
   return 0;
-#endif
+#endif /* ! MHD_TCP_CORK_NOPUSH */
 }
 
 
@@ -585,12 +585,15 @@ MHD_socket_create_listen_ (int pf)
 #if defined(MHD_POSIX_SOCKETS) && (defined(SOCK_CLOEXEC) || \
   defined(SOCK_NOSIGPIPE) )
   fd = socket (pf,
-               SOCK_STREAM | SOCK_CLOEXEC | MAYBE_SOCK_NOSIGPIPE,
+               SOCK_STREAM | SOCK_CLOEXEC | SOCK_NOSIGPIPE_OR_ZERO,
                0);
-  cloexec_set = (MAYBE_SOCK_CLOEXEC != 0);
+  if (MHD_INVALID_SOCKET != fd)
+  {
+    cloexec_set = (SOCK_CLOEXEC_OR_ZERO != 0);
 #if defined(SOCK_NOSIGPIPE) || defined(MHD_socket_nosignal_)
-  nosigpipe_set = (MAYBE_SOCK_NOSIGPIPE != 0);
+    nosigpipe_set = (SOCK_NOSIGPIPE_OR_ZERO != 0);
 #endif /* SOCK_NOSIGPIPE ||  MHD_socket_nosignal_ */
+  }
 #elif defined(MHD_WINSOCK_SOCKETS) && defined (WSA_FLAG_NO_HANDLE_INHERIT)
   fd = WSASocketW (pf,
                    SOCK_STREAM,
@@ -608,6 +611,9 @@ MHD_socket_create_listen_ (int pf)
                  SOCK_STREAM,
                  0);
     cloexec_set = 0;
+#if defined(SOCK_NOSIGPIPE) || defined(MHD_socket_nosignal_)
+    nosigpipe_set = 0;
+#endif /* SOCK_NOSIGPIPE ||  MHD_socket_nosignal_ */
   }
   if (MHD_INVALID_SOCKET == fd)
     return MHD_INVALID_SOCKET;
@@ -615,7 +621,7 @@ MHD_socket_create_listen_ (int pf)
 #if defined(MHD_socket_nosignal_)
   if ( (! nosigpipe_set) &&
        (0 == MHD_socket_nosignal_ (fd)) &&
-       (0 == MAYBE_MSG_NOSIGNAL) )
+       (0 == MSG_NOSIGNAL_OR_ZERO) )
   {
     /* SIGPIPE disable is possible on this platform
      * (so application expect that it will be disabled),
