@@ -43,11 +43,11 @@
 #include "gauger.h"
 #include "mhd_has_in_name.h"
 
-#if defined(CPU_COUNT) && (CPU_COUNT + 0) < 2
-#undef CPU_COUNT
+#if defined(MHD_CPU_COUNT) && (MHD_CPU_COUNT + 0) < 2
+#undef MHD_CPU_COUNT
 #endif
-#if ! defined(CPU_COUNT)
-#define CPU_COUNT 2
+#if ! defined(MHD_CPU_COUNT)
+#define MHD_CPU_COUNT 2
 #endif
 
 /**
@@ -55,8 +55,12 @@
  * test (total number of requests will be ROUNDS * PAR).
  * Ensure that free ports are not exhausted during test.
  */
-#if CPU_COUNT > 8
-#define ROUNDS (1 + (30000 / 12) / CPU_COUNT)
+#if MHD_CPU_COUNT > 8
+#ifndef _WIN32
+#define ROUNDS (1 + (30000 / 12) / MHD_CPU_COUNT)
+#else /* _WIN32 */
+#define ROUNDS (1 + (3000 / 12) / MHD_CPU_COUNT)
+#endif /* _WIN32 */
 #else
 #define ROUNDS 500
 #endif
@@ -64,7 +68,7 @@
 /**
  * How many requests do we do in parallel?
  */
-#define PAR CPU_COUNT
+#define PAR MHD_CPU_COUNT
 
 /**
  * Do we use HTTP 1.1?
@@ -368,7 +372,8 @@ testMultithreadedPoolGet (int port, int poll_flag)
   d = MHD_start_daemon (MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG
                         | poll_flag,
                         port, NULL, NULL, &ahc_echo, "GET",
-                        MHD_OPTION_THREAD_POOL_SIZE, CPU_COUNT, MHD_OPTION_END);
+                        MHD_OPTION_THREAD_POOL_SIZE, MHD_CPU_COUNT,
+                        MHD_OPTION_END);
   if (d == NULL)
     return 16;
   if (0 == port)
