@@ -45,11 +45,11 @@
 
 #include "mhd_has_in_name.h"
 
-#if defined(CPU_COUNT) && (CPU_COUNT + 0) < 2
-#undef CPU_COUNT
+#if defined(MHD_CPU_COUNT) && (MHD_CPU_COUNT + 0) < 2
+#undef MHD_CPU_COUNT
 #endif
-#if ! defined(CPU_COUNT)
-#define CPU_COUNT 2
+#if ! defined(MHD_CPU_COUNT)
+#define MHD_CPU_COUNT 2
 #endif
 
 #define POST_DATA "name=daniel&project=curl"
@@ -341,7 +341,7 @@ testMultithreadedPoolPost ()
   cbc.pos = 0;
   d = MHD_start_daemon (MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
                         port, NULL, NULL, &ahc_echo, NULL,
-                        MHD_OPTION_THREAD_POOL_SIZE, CPU_COUNT,
+                        MHD_OPTION_THREAD_POOL_SIZE, MHD_CPU_COUNT,
                         MHD_OPTION_NOTIFY_COMPLETED, &completed_cb, NULL,
                         MHD_OPTION_END);
   if (d == NULL)
@@ -573,7 +573,7 @@ ahc_cancel (void *cls,
 {
   struct MHD_Response *response;
   enum MHD_Result ret;
-  (void) cls; (void) url; (void) version;            /* Unused. Silent compiler warning. */
+  (void) cls; (void) url; (void) version;          /* Unused. Silent compiler warning. */
   (void) upload_data; (void) upload_data_size;     /* Unused. Silent compiler warning. */
 
   if (0 != strcasecmp ("POST", method))
