@@ -40,11 +40,11 @@
 #include <sys/socket.h>
 #endif
 
-#if defined(CPU_COUNT) && (CPU_COUNT + 0) < 2
-#undef CPU_COUNT
+#if defined(MHD_CPU_COUNT) && (MHD_CPU_COUNT + 0) < 2
+#undef MHD_CPU_COUNT
 #endif
-#if ! defined(CPU_COUNT)
-#define CPU_COUNT 2
+#if ! defined(MHD_CPU_COUNT)
+#define MHD_CPU_COUNT 2
 #endif
 
 
@@ -553,20 +553,20 @@ main (int argc, char *const *argv)
     errorCount += testGet (MHD_USE_INTERNAL_POLLING_THREAD, 0, 0);
     errorCount += testGet (MHD_USE_THREAD_PER_CONNECTION
                            | MHD_USE_INTERNAL_POLLING_THREAD, 0, 0);
-    errorCount += testGet (MHD_USE_INTERNAL_POLLING_THREAD, CPU_COUNT, 0);
+    errorCount += testGet (MHD_USE_INTERNAL_POLLING_THREAD, MHD_CPU_COUNT, 0);
     if (MHD_YES == MHD_is_feature_supported (MHD_FEATURE_POLL))
     {
       errorCount += testGet (MHD_USE_INTERNAL_POLLING_THREAD, 0, MHD_USE_POLL);
       errorCount += testGet (MHD_USE_THREAD_PER_CONNECTION
                              | MHD_USE_INTERNAL_POLLING_THREAD, 0,
                              MHD_USE_POLL);
-      errorCount += testGet (MHD_USE_INTERNAL_POLLING_THREAD, CPU_COUNT,
+      errorCount += testGet (MHD_USE_INTERNAL_POLLING_THREAD, MHD_CPU_COUNT,
                              MHD_USE_POLL);
     }
     if (MHD_YES == MHD_is_feature_supported (MHD_FEATURE_EPOLL))
     {
       errorCount += testGet (MHD_USE_INTERNAL_POLLING_THREAD, 0, MHD_USE_EPOLL);
-      errorCount += testGet (MHD_USE_INTERNAL_POLLING_THREAD, CPU_COUNT,
+      errorCount += testGet (MHD_USE_INTERNAL_POLLING_THREAD, MHD_CPU_COUNT,
                              MHD_USE_EPOLL);
     }
   }
